function [g, violated] = check_feasible_constraints(n_links, sim_data, limits, chromosome)
    
%     phi_max     = limits(1);
%     phi_dot_max = limits(2);
%     u_max       = limits(3);
    alpha_max   = limits(4);
    omega_max   = limits(5);
    delta_max   = limits(6);
    
    % Saturation of torque input
    u_max=2.3*1000; %2.3Nm for Mamba joints

    % Saturation of angular speed
    phi_max=90*pi/180; %90 degrees

    % Saturation of angular speed
    phi_dot_max=429*pi/180; %429 degrees/sec

    v            = sim_data.state_vector;
    phi          = v(:, 2*n_links+5:3*n_links+3);
    phi_dot      = v(:, 3*n_links+4:4*n_links+2);
    u            = sim_data.input;
    a 			 = 0;
    
    % The total number of constraints is calculated by taking the
    % consideration of each time step in the simulation, where the
    % number of time steps is the size(u,2)
    n_time_steps = size(u,2);
    
    % Create a constraint set g. Note that the constraints violation are
    % considered at each time sample from [0,stop_time] calcuted in ode23tb
    total_constraints = 6*(n_links-1)*n_time_steps + 6;   
    g  = a*ones(total_constraints,1);
    violated = 0;
    
    %% Description/Outline
    %
    %
    % The goal with creating a constraint set g is to include the
    % constraints into the minimization problem, so that we get an
    % unconstrained problem min([f_obj, g_constaints]) to optimize.
    % We denote the constraint set to be, 
    %   1) If constraint i is violated, e.g. constraint_i > 0
    %                                   g_i = a + b_i*(constraint_i)
    %   2) else consraint i is nonviolated, e.g. constraint_i <= 0
    %                                   g_i = a
    % where parameter a is a scalar and b_i is a weight parameter
    % Since the constraints are already well scaled, b is set as 1
    %
    %
        
    % Compute the constraints of the snake at each time sample
    for i = 1:n_time_steps
        for j = 1:n_links-1
            % The lower bound of phi
            if -(phi(i,j) + phi_max) > 0
                violated = violated + 1;
                g((i-1)*(n_links-1)*6+(j-1)*6+1) = a + (-(phi(i,j)+phi_max));
            end
            % The upper bound of phi
            if phi(i,j)-phi_max > 0
                violated = violated + 1;
                g((i-1)*(n_links-1)*6+(j-1)*6+2) = a + phi(i,j)-phi_max;
            end
            % The lower bound of phi_dot
            if -(phi_dot(i,j) + phi_dot_max) > 0
                violated = violated + 1;
                g((i-1)*(n_links-1)*6+(j-1)*6+3) = a + (-(phi_dot(i,j)+phi_dot_max));
            end
            % The upper bound of phi_dot
            if phi_dot(i,j)-phi_dot_max > 0
                violated = violated + 1;
                g((i-1)*(n_links-1)*6+(j-1)*6+4) = a + phi_dot(i,j)-phi_dot_max;
            end
            % The lower bound of the joint input
            if -(u(j,i) + u_max) > 0
                violated = violated + 1;
                g((i-1)*(n_links-1)*6+(j-1)*6+5) = a + (-(u(j,i)+u_max));
            end
            % The upper bound of the joint input
            if u(j,i)-u_max > 0
                violated = violated + 1;
                g((i-1)*(n_links-1)*6+(j-1)*6+6) = a + u(j,i)-u_max;
            end
        end
    end            
end